@@ -3,8 +3,6 @@ import torch.nn as nn
 
 from .lightning import M
 
-DEVICE = 'cuda:0' if torch.cuda.is_available() else 'cpu'
-
 import math
 from collections import OrderedDict
 
@@ -268,9 +266,9 @@ class Conv(M):
                  form: int = -1):
         super(Conv, self).__init__()
         self.form = form
-        self.to(DEVICE)
+
         self.conv = nn.Conv2d(c1, c2, kernel_size=k, stride=s,
-                              padding=p if p is not None else (1 if k == 3 else 0), groups=g).to(DEVICE)
+                              padding=p if p is not None else (1 if k == 3 else 0), groups=g)
         nn.init.xavier_normal_(self.conv.weight.data)
 
         self.activation = (
@@ -374,7 +372,7 @@ class ResidualBlock(M):
         super(ResidualBlock, self).__init__()
         self.use_residual = use_residual
         self.n = n
-        self.to(DEVICE)
+
         self.layer = nn.ModuleList()
         self.form = form
 
